from setuptools import setup, find_packages
from pathlib import Path

# Read long description from README.md
long_description = (Path(__file__).parent / "README.md").read_text(encoding="utf-8")

setup(
    name="overload-function-1",
    version="0.1.0",
    description="A Python decorator for function overloading based on argument types",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="HuangHaoHUa",
    author_email="13140752715@example.com",
    url="https://github.com/Locked-chess-official/overload-function",
    license="MIT",
    py_modules=["overload_function"],
    python_requires=">=3.7",
    install_requires=[
        "typeguard>=2.13.0",
        "typing-extensions>=3.10.0;python_version<'3.8'",
    ],
    extras_require={
        "dev": [
            "pytest>=6.0",
            "pytest-cov>=2.0",
            "mypy>=0.910",
            "flake8>=3.9",
            "black>=21.0",
        ],
        "docs": [
            "sphinx>=4.0",
            "sphinx-rtd-theme>=0.5",
        ],
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Typing :: Typed",
    ],
    keywords="overload function decorator type checking",
    project_urls={
        "Bug Reports": "https://github.com/your-repo/overload-function/issues",
        "Source": "https://github.com/your-repo/overload-function",
    },
)
